<?php
/*********************************************
  CPG Dragonfly™ CMS
  ********************************************
  Copyright © 2004 - 2005 by CPG-Nuke Dev Team
  http://www.dragonflycms.com

  Dragonfly is released under the terms and conditions
  of the GNU GPL version 2 or any later version

  $Source: /cvs/html/modules/Your_Account/blocks/comments.php,v $
  $Revision: 9.3.8.1 $
  $Author: nanocaiordo $
  $Date: 2008/08/26 12:46:56 $
**********************************************/
if (!defined('CPG_NUKE')) { exit; }
if (is_user()) {
// Last 10 Comments
$result = $db->sql_query("SELECT tid, sid, subject FROM ".$prefix."_comments WHERE name='$username' ORDER BY tid DESC LIMIT 0,10");
if ($db->sql_numrows($result)) {
	echo '<br />';
	OpenTable();
	echo '<div align="left"><strong>'.$username.'\'s '._LAST10COMMENT.':</strong><ul>';
	while (list($tid, $sid, $subject) = $db->sql_fetchrow($result)) {
		echo '<li><a href="'.getlink('News&amp;file=article&amp;sid='.$sid.'#'.$tid).'">'.$subject.'</a></li>';
	}
	echo '</ul></div>';
	CloseTable();
}
}